@@ -3,6 +3,7 @@ from collections.abc import ItemsView, KeysView, ValuesView
 from functools import partial
 from inspect import isclass, ismodule
 from pathlib import Path
+from types import MethodType
 from typing import Any, Callable, Generator, List, Optional, Type, Union
 
 from .config import RegistryConfig
@@ -95,10 +96,11 @@ class _Registry(dict):
                     continue
 
                 if parent_cls is Registry:
-                    # Only register to Registry if this is a root call.
-                    if root:
-                        parent_registry.register(obj, name=name, aliases=aliases)
-                elif root or parent_registry.config.recursive:
+                    # Never register to the base Registry class.
+                    # Unwanted cross-library interactions may occur, otherwise.
+                    continue
+
+                if root or parent_registry.config.recursive:
                     parent_registry.register(obj, name=name, aliases=aliases)
 
         # Register aliases
@@ -155,26 +157,22 @@ class _DictMixin:
         self.__registry__.clear()
 
 
-class _RedirectMethod(object):
-    """Dispatches call depending if it was called from a Class or an instance."""
+class MethodDescriptor(object):
+    """
+    Non-data-descriptor that dispatches depending if it was called from a Class or an instance.
+    """
 
-    def __init__(self, obj_method, name):
-        self.obj_method = obj_method
-        self.cls_method = name
+    def __init__(self, user_method, registry_method):
+        self.user_method = user_method
+        self.registry_method = registry_method
 
-    def __get__(self, obj, cls):
+    def __get__(self, obj, objtype):
         if obj is None:
-            # invoked directly from Class
-            def redirect(*args, **kwargs):
-                return self.cls_method(cls, *args, **kwargs)
-
-            return redirect
+            # invoked from class
+            return MethodType(self.registry_method, objtype)
         else:
-            # invoked from instance
-            def redirect(*args, **kwargs):
-                return self.obj_method(obj, *args, **kwargs)
-
-            return redirect
+            # invoked from instance of class
+            return MethodType(self.user_method, obj)
 
 
 class RegistryMeta(ABCMeta, _DictMixin):
@@ -236,7 +234,7 @@ class RegistryMeta(ABCMeta, _DictMixin):
         namespace["__registry__"] = _Registry(registry_config, name=registry_name)
 
         if namespace["__registry__"].config.redirect:
-            for key in [
+            for method_name in [
                 "__getitem__",
                 "__iter__",
                 "__len__",
@@ -247,10 +245,12 @@ class RegistryMeta(ABCMeta, _DictMixin):
                 "get",
                 "clear",
             ]:
-                if key in namespace and not isinstance(
-                    namespace[key], (staticmethod, classmethod)
+                if method_name in namespace and not isinstance(
+                    namespace[method_name], (staticmethod, classmethod)
                 ):
-                    namespace[key] = _RedirectMethod(namespace[key], getattr(cls, key))
+                    namespace[method_name] = MethodDescriptor(
+                        namespace[method_name], getattr(cls, method_name)
+                    )
 
         # We cannot defer class creation any further.
         # This will call hooks like __init_subclass__
@@ -298,7 +298,7 @@ class Registry(metaclass=RegistryMeta):
             return super().__new__(cls)
 
 
-class RegistryDecorator(Registry, _DictMixin):
+class RegistryDecorator(Registry, _DictMixin, skip=True):
     __name__: str
 
     def __init__(self, objs=None, /, **config):
